@@ -1,12 +1,13 @@
 package IPC::System::Options;
 
-our $DATE = '2016-01-02'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-06-04'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use strict;
 use warnings;
 
 use Proc::ChildError qw(explain_child_error);
+use String::ShellQuote;
 
 my $log;
 our %Global_Opts;
@@ -31,6 +32,19 @@ sub import {
     }
 }
 
+sub _quote {
+    if (@_ == 1) {
+        return $_[0];
+    }
+
+    if ($^O eq 'MSWin32') {
+        require Win32::ShellQuote;
+        return Win32::ShellQuote::quote_system_string(@_);
+    } else {
+        return join(" ", map { shell_quote($_) } @_);
+    }
+}
+
 sub _system_or_backtick_or_run {
     my $which = shift;
     my $opts = ref($_[0]) eq 'HASH' ? shift : {};
@@ -96,7 +110,7 @@ sub _system_or_backtick_or_run {
         my $doit = sub {
             if ($opts->{shell}) {
                 # force the use of shell
-                $res = system join(" ", @args);
+                $res = system _quote(@args);
             } elsif (defined $opts->{shell}) {
                 # forbid shell
                 $res = system {$args[0]} @args;
@@ -112,7 +126,7 @@ sub _system_or_backtick_or_run {
     } elsif ($which eq 'backtick') {
 
         $wa = wantarray;
-        my $cmd = join " ", @args;
+        my $cmd = _quote(@args);
         $log->tracef("qx(%s), env=%s", $cmd, \%set_env) if $opts->{log};
         my $doit = sub {
             if ($wa) {
@@ -248,7 +262,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.24 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-01-02.
+This document describes version 0.25 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-06-04.
 
 =head1 SYNOPSIS
 
